<?php

/***************************************************************
 *	Copyright notice
 *
 *	(c) 2006 René Fritz <r.fritz at colorcube.de>
 *	(c) 2006 Fabien Udriot <fabien.udriot@ecodev.ch>
 *	All rights reserved
 *
 *	This script is part of the TYPO3 project. The TYPO3 project is
 *	free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	The GNU General Public License can be found at
 *	http://www.gnu.org/copyleft/gpl.html.
 *
 *	This script is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
 *	GNU General Public License for more details.
 *
 *	This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * THIS CLASS COULD BE A FIRST DRAFT FOR A DAM FRONTEND API
 *
 * (...)
 *
 */

require_once(PATH_txdam.'lib/class.tx_dam_selectionquery.php');
require_once(PATH_txdam.'lib/class.tx_dam_selstorage.php');

class tx_damSelector{


	/**
	 * If true, display some debug.
	 * @var boolean
	 */
	var $debugQuery = false;

	/**
	 * If true, display some sql debug
	 * @var boolean
	 */
	var $debugQueryParts = false;

	/**
	 * Which field are selected ? Comma separated fields. By default all fields are selected.
	 * @var string
	 */
	var $field = '*';

	/**
	 * Table name of the selection
	 * @var string
	 */
	var $table = 'tx_dam';

	/**
	 * Number of maximum selected medias (LIMIT). 0 means no limit.
	 * @var int
	 */
	var $max = 0;

	/**
	 * Corresponds to the first record in a SQL SELECT
	 * @var int
	 */
	var $begin = 0;


	/**
	 * Sorting field, example : $sort = 'uid DESC';
	 * @var string
	 */
	var $sort = '';


	/**
	 * Number of records (should be private)
	 * @var string
	 */
	var $count = 0;


	/**
	 * @return int $this->count
	 */
	function getCount($selection=''){
		if($selection != ''){
			$this->getMedias($selection);
		}
		return $this->count;
	}

	/**
	 * @param int $selection (tx_dam_selection.uid) or string $selection (string definition)
	 * @return array $dam_items
	 */
	function getMedias($selection){
		//init the dam selector
		$this->init($selection);
		$dam_items = array();

		// Get number of records:
		$this->damSel->execSelectionQuery(true);

		if ($this->damSel->error) $this->addFatalError('SQL ERROR: '.$this->damSel->error);

		$this->count = $this->damSel->pointer->countTotal;

		if($this->count) {

			// Make listing query:
			$res = $this->damSel->execSelectionQuery(false);
			while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)){
				$dam_items[] = $row;
			}
		}
		return $dam_items;
	}

	/**
	 * @param int $selection (tx_dam_selection.uid) or string $selection (string definition)
	 * @param string $field
	 * @return array $dam_items
	 */
	function getMediaValues($selection,$field = 'uid'){

		$this->field = $field;

		//init the dam selector
		$this->init($selection);
		$dam_items = array();
		// Get number of records:
		$this->damSel->execSelectionQuery(true);

		if ($this->damSel->error) $this->addFatalError('SQL ERROR: '.$this->damSel->error);

		$this->count = $this->damSel->pointer->countTotal;

		if($this->count) {

			// Make listing query:
			$res = $this->damSel->execSelectionQuery(false);

			while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)){
				$dam_items[] = $row[$field];
			}
		}
		return $dam_items;
	}

	/***************************************
	 *
	 *	 Initialize
	 *
	 ***************************************/

	/**
	 * Initialize all the needed stuff
	 *
	 * @param int $selection (tx_dam_selection.uid) or string $selection (string definition)
	 * @return	void
	 */
	function init($selection){
		$this->damSel = t3lib_div::makeInstance('tx_dam_selectionQuery');
		// init pointer
		$this->damSel->initPointer($this->piVars['pointer'], $this->internal['results_at_a_time'], $this->internal['maxPages']);

		// init selection
		$SOBE_dummy = NULL; // we need to pass a reference - that's why a dummy var is used
		$this->damSel->initSelection($SOBE_dummy /*$GLOBALS['SOBE']*/, $GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['dam']['selectionClasses'], 'tx_dam', 'tx_dam_select');

		// init querygen
		$this->damSel->initQueryGen();

		//		$pidList = ($value = $this->pi_getConfigSelection('pidInList')) ? $value : ( ($pid=tx_dam::config_getValue('plugin.defaults.pid')) ? $pid : tx_dam_db::getPid());
		# TODO : $pidList doesn't affect anything in initFESelect()-> check why ?
		$pidList = 1;
		$this->damSel->qg->initFESelect($this->table, $pidList);
		$this->damSel->qg->addSelectFields($this->field);

		// fetch stored selection can be a (string) definition or a (int) tx_dam_selection.uid
		$selStorage = t3lib_div::makeInstance('tx_dam_selStorage');
		if(unserialize($selection)){
			$definition = $this->damSel->sl->unserialize($selection);
			$this->damSel->sl->mergeSelection($definition);
		}
		else{
			$selStorage->initStorage($selection);

			foreach ($selStorage->storedSettings as $uid => $storageArr) {
				$definition = $this->damSel->sl->unserialize($storageArr['definition']);
				$this->damSel->sl->mergeSelection($definition);
			}
		}

		$this->damSel->addSelectionToQuery();

		//
		// add sorting
		//
		if($this->sort != ''){
			$this->damSel->qg->addOrderBy($this->sort);
			# TODO : can we delete the code ? 
			// old code By Rene,
			//		if ($value = $this->pi_getConfigSelection('orderBy','','','','ts:override'))
		}

		//
		// add limit
		//
		if($this->max != 0){
			$this->damSel->addLimitToQuery($this->max, $this->begin);
			# TODO : can we delete the code ?
			// old code By Rene
			//		$max = $this->pi_getConfigSelection('max','','',$this->damSel->pointer->itemsPerPage);
			//		$begin = $this->pi_getConfigSelection('begin','','',$this->damSel->pointer->firstItemNum);
		}

		$this->initDebug();
	}


	/**
	 * Initialize the debug output
	 *
	 * @return	void
	 */
	function initDebug(){
		//some debug possibility
		if($this->debugQuery){
			debug($this->damSel->qg->query);
		}
		if($this->debugQueryParts){
			debug($this->damSel->qg->getQueryParts());
		}
	}

}

?>
